pub struct WindowsFilesystemUsage {
pub timestamp: i64,
pub fs_id: Option<FilesystemIdentifier>,
pub used_bytes: Option<UInt64Value>,
}Expand description
WindowsFilesystemUsage provides the filesystem usage information specific to Windows.
Fields
timestamp: i64Timestamp in nanoseconds at which the information were collected. Must be > 0.
fs_id: Option<FilesystemIdentifier>The unique identifier of the filesystem.
used_bytes: Option<UInt64Value>UsedBytes represents the bytes used for images on the filesystem. This may differ from the total bytes used on the filesystem and may not equal CapacityBytes - AvailableBytes.