pub struct WindowsMemoryUsage {
pub timestamp: i64,
pub working_set_bytes: Option<UInt64Value>,
pub available_bytes: Option<UInt64Value>,
pub page_faults: Option<UInt64Value>,
pub commit_memory_bytes: Option<UInt64Value>,
}Expand description
WindowsMemoryUsage provides the memory usage information specific to Windows
Fields
timestamp: i64Timestamp in nanoseconds at which the information were collected. Must be > 0.
working_set_bytes: Option<UInt64Value>The amount of working set memory in bytes.
available_bytes: Option<UInt64Value>Available memory for use. This is defined as the memory limit - commit_memory_bytes.
page_faults: Option<UInt64Value>Cumulative number of page faults.
commit_memory_bytes: Option<UInt64Value>Total commit memory in use. Commit memory is total of physical and virtual memory in use.