pub struct WindowsNamespaceOption {
pub network: i32,
}Expand description
WindowsNamespaceOption provides options for Windows namespaces.
Fields
network: i32Network namespace for this container/sandbox. Namespaces currently set by the kubelet: POD, NODE
Implementations
Sourceimpl WindowsNamespaceOption
impl WindowsNamespaceOption
Sourcepub fn network(&self) -> NamespaceMode
pub fn network(&self) -> NamespaceMode
Returns the enum value of network, or the default if the field is set to an invalid enum value.
Sourcepub fn set_network(&mut self, value: NamespaceMode)
pub fn set_network(&mut self, value: NamespaceMode)
Sets network to the provided enum value.